package envoy.data;

import java.io.Serializable;
import java.util.List;

/**
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>Contacts.java</strong><br>
 * Created: <strong>02.01.2020</strong><br>
 * 
 * @author Kai S. K. Engelbart
 * @since Envoy Common v0.2-alpha
 */
public class Contacts implements Serializable {

	private final long			userId;
	private final List<User>	contacts;

	private static final long serialVersionUID = 136970804968152871L;

	/**
	 * Creates an instance of {@link Contacts}.
	 *
	 * @param userId   the ID of the user this contacts belong to
	 * @param contacts the contact list
	 * @since Envoy Common v0.2-alpha
	 */
	public Contacts(long userId, List<User> contacts) {
		this.userId		= userId;
		this.contacts	= contacts;
	}

	@Override
	public String toString() { return String.format("Contacts[%s]", contacts); }

	/**
	 * @return the ID of the user this contacts belong to
	 * @since Envoy Common v0.2-alpha
	 */
	public long getUserId() { return userId; }

	/**
	 * @return a list of users messages can be sent to
	 * @since Envoy Common v0.2-alpha
	 */
	public List<User> getContacts() { return contacts; }
}
